@@ -38,6 +38,11 @@ func ResponsePropertyAnyOfUpdatedCheck(diffReport *diff.Diff, operationsSources
 						continue
 					}
 
+					// Check for suppression by ListOfTypes checker
+					if shouldSuppressOneOfSchemaChangedForListOfTypes(mediaTypeDiff.SchemaDiff) {
+						continue
+					}
+
 					if mediaTypeDiff.SchemaDiff.AnyOfDiff != nil && len(mediaTypeDiff.SchemaDiff.AnyOfDiff.Added) > 0 {
 
 						result = append(result, NewApiChange(
@@ -72,6 +77,11 @@ func ResponsePropertyAnyOfUpdatedCheck(diffReport *diff.Diff, operationsSources
 								return
 							}
 
+							// Check for suppression by ListOfTypes checker
+							if shouldSuppressPropertyOneOfSchemaChangedForListOfTypes(propertyDiff) {
+								return
+							}
+
 							if len(propertyDiff.AnyOfDiff.Added) > 0 {
 
 								result = append(result, NewApiChange(
