@@ -3,8 +3,8 @@ package checker_test
 import (
 	"testing"
 
+	"github.com/oasdiff/oasdiff/checker"
 	"github.com/stretchr/testify/require"
-	"github.com/tufin/oasdiff/checker"
 )
 
 func TestColorMode_Always(t *testing.T) {
