@@ -3,8 +3,8 @@ package diff_test
 import (
 	"testing"
 
+	"github.com/oasdiff/oasdiff/diff"
 	"github.com/stretchr/testify/require"
-	"github.com/tufin/oasdiff/diff"
 )
 
 func TestConfig_Default(t *testing.T) {
