@@ -42,7 +42,7 @@ func getEncodingDiffInternal(config *Config, state *state, value1, value2 *opena
 		return nil, fmt.Errorf("encoding is nil")
 	}
 
-	result.ExtensionsDiff, err = getExtensionsDiff(config, state, value1.Extensions, value2.Extensions)
+	result.ExtensionsDiff, err = getExtensionsDiff(config, value1.Extensions, value2.Extensions)
 	if err != nil {
 		return nil, err
 	}
