@@ -174,20 +174,3 @@ func filterPathsByExtensionInternal(paths *openapi3.Paths, r *regexp.Regexp) {
 		}
 	}
 }
-
-// Patch applies the patch to paths
-func (pathsDiff *PathsDiff) Patch(paths *openapi3.Paths) error {
-
-	if pathsDiff.Empty() {
-		return nil
-	}
-
-	for path, pathDiff := range pathsDiff.Modified {
-		err := pathDiff.Patch(paths.Find(path))
-		if err != nil {
-			return err
-		}
-	}
-
-	return nil
-}
