@@ -607,6 +607,10 @@ func (r *report) printMediaType(d *diff.MediaTypeDiff) {
 		return
 	}
 
+	if !d.NameDiff.Empty() {
+		r.printValue(d.NameDiff.NameDiff, "Name")
+	}
+
 	if !d.ExtensionsDiff.Empty() {
 		r.print("Extensions changed")
 		r.indent().printExtensions(d.ExtensionsDiff)
